pub type MaintenancePrepareFn = for<'connection> fn(&Transaction<'connection>) -> Result<MaintenancePrepareReport, Error>;Expand description
Offline preparation callback retained under the ledger migration transaction.
pub type MaintenancePrepareFn = for<'connection> fn(&Transaction<'connection>) -> Result<MaintenancePrepareReport, Error>;Offline preparation callback retained under the ledger migration transaction.